@@ -176,7 +176,10 @@ class MediaReview:
             },
         )
         # Set review metadata
-        metadata = ET.SubElement(review, "metadata", self.metadata)
+        # Sentinel casting for values to string
+        metadata = ET.SubElement(
+            review, "metadata", dict([[k, str(v)] for k, v in self.metadata.items()])
+        )
 
         # Statuses
         statuses = ET.SubElement(review, "statuses")
@@ -231,7 +234,10 @@ class MediaReview:
                 contents.append(content)
 
             # Set note metadata
-            metadata = ET.SubElement(note, "metadata", n.metadata)
+            # Sentinel casting for values to string
+            metadata = ET.SubElement(
+                note, "metadata", dict([[k, str(v)] for k, v in n.metadata.items()])
+            )
 
             notes.append(note)
 
